#encoding:utf-8
from django.db import models
from datetime import datetime


'''
    La clase cuestionario genera un objeto que contiene clave, nombre del cuestionario
    y un color que define al cuestionario
'''
class Cuestionario(models.Model):
    clave=models.CharField("Clave",max_length=50)
    nombre_cuestionario=models.CharField("Nombre", max_length=50)
    color_area=models.CharField("Color",max_length=50)

    def __unicode__(self):
        return self.nombre_cuestionario

"""
    Clase alumno  genera un objeto que contiene los siguentes datos:
    nombre del alumno, apellido paterno y materno, y la fecha hace referencia a la fecha cuando realizo
    el cuestionario, tambien un personal pertenece a un cuestinario

    """
class Dependencia(models.Model):

    clave=models.CharField("Clave",max_length=50)
    nombre=models.CharField("Dependencia",max_length=250)
    ejercicio=models.IntegerField("ejercicio fiscal ",max_length=50)

    class meta:
        ordering = [
            '-nombre'
        ]


    def __unicode__(self):
        return self.nombre


class Alumno(models.Model):

    nombre_alumno=models.CharField("Nombre",max_length=50)
    appat=models.CharField("Apellido Paterno",max_length=50)
    apma=models.CharField("Apellido Materno",max_length=50)
    fecha=models.DateTimeField("Fecha de Registro",auto_now=True)
    cuestionario=models.ForeignKey(Cuestionario, verbose_name="Cuestionario")
    dependencia=models.ForeignKey(Dependencia, verbose_name="Dependencia")
    area=models.CharField("Area en la que labora",max_length=100)
    #directivo=models.BooleanField("Respuesta Correcta", null=True, blank=True)
    #correo=models.CharField("Correo", null=True, blank=True)

    def __unicode__(self):
        return self.nombre_alumno
class Directivo(models.Model):

    nombre_directivo=models.CharField("Nombre",max_length=50)
    appat=models.CharField("Apellido Paterno",max_length=50)
    apma=models.CharField("Apellido Materno",max_length=50)
    fecha=models.DateTimeField("Fecha de Registro",auto_now=True)
    cuestionario=models.ForeignKey(Cuestionario, verbose_name="Cuestionario")
    dependencia=models.ForeignKey(Dependencia, verbose_name="Dependencia")
    correo=models.CharField("Correo",max_length=50)

    def __unicode__(self):
        return self.nombre_directivo


"""
    Clase Area se define con el area al cual pertenece el cuestionario
    que se aplicara.
    """
class Area(models.Model):

    cuestionario=models.ForeignKey(Cuestionario, verbose_name="Cuestionario")
    nombre_area=models.CharField("Nombre",max_length=50)
    def __unicode__(self):
        return self.nombre_area

"""
    La clase  define la pregunta que se almacenara, esta
    se asocia  a una area en particular

    """

class Pregunta(models.Model):

    area=models.ForeignKey(Area, verbose_name="Area de la Pregunta")
    nombre_pregunta=models.CharField("Pregunta", max_length=1000)
    def __unicode__(self):
        return self.nombre_pregunta


"""
    Clase respuesta define la respuestas que se asocian a una pregunta
    en particular y contiene un dato booleano para definir cual respuesta
    es la correcta

    """
class Respuesta(models.Model):

    pregunta= models.ForeignKey(Pregunta, verbose_name="Pregunta")
    nom_respuesta=models.CharField("Respuesta", max_length=1000)
    acierto=models.BooleanField("Respuesta Correcta")


    def __unicode__(self):
        return self.nom_respuesta


"""
    Clase Resultado  define los  respuestas de cada alumno, asignando el valor 1 para los aciertos y asignando 0 en caso contrario.


    """
class Resultado(models.Model):

    alumno=models.ForeignKey(Alumno, verbose_name="Nombre del alumno")
    respuesta=models.ForeignKey(Respuesta, verbose_name="Respuesta")
    cont_respuesta=models.IntegerField("Contador",default=0)


    def __unicode__(self):

        return u'%s' % self.cont_respuesta
